7544fd2a03bf573a9a12195d86a2fc082a88de78
tdreszer
  Tue Apr 5 15:17:56 2011 -0700
Tightened the screws on searching by mdb vars where the search is either for files or tables
diff --git src/hg/inc/searchTracks.h src/hg/inc/searchTracks.h
index d5a141a..2236cb6 100644
--- src/hg/inc/searchTracks.h
+++ src/hg/inc/searchTracks.h
@@ -28,25 +28,22 @@
     filesTab    = 2,
 };
 
 void getSearchTrixFile(char *database, char *buf, int len);
 // Fill-in the name of the track search trix file
 
 boolean isSearchTracksSupported(char *database, struct cart *cart);
 // Return TRUE if searchTracks is supported for this database and javascript is supported too
 
 struct slPair *fileFormatSearchWhiteList(void);
 // Gets the whitelist of approved file formats that is allowed for search
 
 char *fileFormatSelectHtml(char *name, char *selected, char *extraHtml);
 // returns an allocated string of HTML for the fileType select drop down
 
-struct slPair *mdbVarsRelevant(struct sqlConnection *conn);
-// returns a white list of mdb vars that are relevant to the currect DB
-
 struct slPair *mdbSelectPairs(struct cart *cart,enum searchTab selectedTab, struct slPair *mdbVars);
 // Returns the current mdb  vars and vals in the table of drop down selects
 
-char *mdbSelectsHtmlRows(struct sqlConnection *conn,struct slPair *mdbSelects, struct slPair *mdbVars,int cols);
-// genereates the html for the table rows containing mdb var and val selects
+char *mdbSelectsHtmlRows(struct sqlConnection *conn,struct slPair *mdbSelects, struct slPair *mdbVars,int cols,boolean fileSearch);
+// generates the html for the table rows containing mdb var and val selects.  Assume tableSearch unless fileSearch
 
 #endif /* SEARCHTRACKS_H */